@@ -10,7 +10,6 @@
 
 #include "ktask.h"
 
-#define __KERNEL__
 #include <linux/sched.h>
 
 
@@ -21,7 +20,13 @@ int kt_pid(void *ktask)
 
 int kt_cpu(void *ktask)
 {
-	return (int)((struct task_struct*)ktask)->processor;
+//	return (int)((struct task_struct*)ktask)->processor;
+	return 0;// ktask->thread_info->cpu
+}
+
+int kt_task(void *ktask)
+{
+	return 0;// ktask->thread_info->task
 }
 
 char * kt_name(void *ktask)
@@ -31,12 +36,12 @@ char * kt_name(void *ktask)
 
 void * kt_next(void *ktask)
 {
-	return (void*)((struct task_struct*)ktask)->next_task;
+	return (void*)((struct task_struct*)ktask)->tasks.next;
 }
 
 void * kt_prev(void *ktask)
 {
-	return (void*)((struct task_struct*)ktask)->prev_task;
+	return (void*)((struct task_struct*)ktask)->tasks.prev;
 }
 
 long kt_state(void *ktask)
